==> u++-5.4.1.tar.gz: u++-5.4.1/src/translator/key.h <==
//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.4.1, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
// 
// key.h -- 
// 
// Author           : Richard A. Stroobosscher
// Created On       : Tue Apr 28 15:39:05 1992
// Last Modified By : Peter A. Buhr
// Last Modified On : Mon Nov 21 15:23:15 2005
// Update Count     : 49
//
// This  library is free  software; you  can redistribute  it and/or  modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
// option) any later version.
// 
// This library is distributed in the  hope that it will be useful, but WITHOUT
// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
// for more details.
// 
// You should  have received a  copy of the  GNU Lesser General  Public License
// along  with this library.
// 


#ifndef __KEY_H__
#define __KEY_H__

struct keyword_t {
    const char *text;
    int value;
};

extern keyword_t key[];

enum key_value_t {
    ASM = 512,
    ATTRIBUTE,						// gcc specific
    AUTO,
    BOOL,
    BREAK,
    CASE,
    CATCH,
    CHAR,
    CLASS,
    COMPLEX,						// gcc specific
    CONST,
    CONST_CAST,
    CONTINUE,
    DEFAULT,
    DELETE,
    DO,
    DOUBLE,
    DYNAMIC_CAST,
    ELSE,
    ENUM,
    EXPLICIT,
    EXPORT,
    EXTENSION,						// gcc specific
    EXTERN,
    FALSE,
    FLOAT,
    FOR,
    FRIEND,
    GOTO,
    IF,
    INLINE,
    INT,
    LONG,
    MUTABLE,
    NAMESPACE,
    NEW,
    OPERATOR,
    PRIVATE,
    PROTECTED,
    PUBLIC,
    REGISTER,
    REINTERPRET_CAST,
    RETURN,
    SHORT,
    SIGNED,
    SIZEOF,
    STATIC,
    STATIC_CAST,
    STRUCT,
    SWITCH,
    TEMPLATE,
    THIS,
    THROW,
    TRUE,
    TRY,
    TYPEDEF,
    TYPEOF,						// gcc specific
    TYPEID,
    TYPENAME,
    UNION,
    UNSIGNED,
    USING,
    VIRTUAL,
    VOID,
    VOLATILE,
    WCHAR_T,
    WHILE,
    
    ACCEPT,
    ACCEPTRETURN,
    ACCEPTWAIT,
    AT,
    COROUTINE,
    DISABLE,
    DUALEVENT,
    ENABLE,
    MUTEX,
    NOMUTEX,
    OR,							// deprecated
    PTASK,
    RAISE,
    RAISEEVENT,						// deprecated
    RESUMEEVENT,
    RTASK,
    RESUME,						// deprecated
    SIGNAL,						// deprecated
    SIGNALBLOCK,					// deprecated
    STASK,
    SUSPEND,						// deprecated
    TASK,
    THROWEVENT,
    TIMEOUT,
    WAIT,						// deprecated
    WITH,
    WHEN,
    UELSE,						// deprecated
    UTHROW,

    ACCEPT_OR,						// pseudo values (i.e., no associated keywords) denotes kinds of definitions
    MEMBER,
    ROUTINE,
};

#endif // __KEY_H__

// Local Variables: //
// compile-command: "gmake install" //
// End: //

==> u++_5.5.0.orig.tar.gz: u++-5.5.0/src/translator/key.h <==
//                              -*- Mode: C++ -*- 
// 
// uC++ Version 5.5.0, Copyright (C) Peter A. Buhr and Richard A. Stroobosscher 1994
// 
// key.h -- 
// 
// Author           : Richard A. Stroobosscher
// Created On       : Tue Apr 28 15:39:05 1992
// Last Modified By : Peter A. Buhr
// Last Modified On : Thu Aug  9 21:25:55 2007
// Update Count     : 59
//
// This  library is free  software; you  can redistribute  it and/or  modify it
// under the terms of the GNU Lesser General Public License as published by the
// Free Software  Foundation; either  version 2.1 of  the License, or  (at your
// option) any later version.
// 
// This library is distributed in the  hope that it will be useful, but WITHOUT
// ANY  WARRANTY;  without even  the  implied  warranty  of MERCHANTABILITY  or
// FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public License
// for more details.
// 
// You should  have received a  copy of the  GNU Lesser General  Public License
// along  with this library.
// 


#ifndef __KEY_H__
#define __KEY_H__

struct keyword_t {
    const char *text;
    int value;
};

extern keyword_t key[];

enum key_value_t {
    ASM = 512,
    ATTRIBUTE,						// gcc specific
    AUTO,
    BOOL,
    BREAK,
    CASE,
    CATCH,
    CHAR,
    CLASS,
    COMPLEX,						// gcc specific
    CONST,
    CONST_CAST,
    CONTINUE,
    DEFAULT,
    DELETE,
    DO,
    DOUBLE,
    DYNAMIC_CAST,
    ELSE,
    ENUM,
    EXPLICIT,
    EXPORT,
    EXTENSION,						// gcc specific
    EXTERN,
    FALSE,
    FLOAT,
    FOR,
    FRIEND,
    GOTO,
    IF,
    INLINE,
    INT,
    LONG,
    MUTABLE,
    NAMESPACE,
    NEW,
    OPERATOR,
    PRIVATE,
    PROTECTED,
    PUBLIC,
    REGISTER,
    REINTERPRET_CAST,
    RESTRICT,
    RETURN,
    SHORT,
    SIGNED,
    SIZEOF,
    STATIC,
    STATIC_CAST,
    STRUCT,
    SWITCH,
    TEMPLATE,
    THIS,
    THREAD,
    THROW,
    TRUE,
    TRY,
    TYPEDEF,
    TYPEOF,						// gcc specific
    TYPEID,
    TYPENAME,
    UNION,
    UNSIGNED,
    USING,
    VIRTUAL,
    VOID,
    VOLATILE,
    WCHAR_T,
    WHILE,

    ACCEPT,
    ACCEPTRETURN,
    ACCEPTWAIT,
    AT,
    COROUTINE,
    DISABLE,
    ENABLE,
    EVENT,
    MUTEX,
    NOMUTEX,
    PTASK,
    RAISE,
    RTASK,
    SELECT,
    STASK,
    TASK,
    TIMEOUT,
    WITH,
    WHEN,
    UTHROW,

    CONN_OR,							// pseudo values (i.e., no associated keywords) denotes kinds of definitions
    CONN_AND,
    SELECT_LP,
    SELECT_RP,
    MEMBER,
    ROUTINE,
};

#endif // __KEY_H__

// Local Variables: //
// compile-command: "gmake install" //
// End: //
